package model;

import sun.reflect.generics.reflectiveObjects.NotImplementedException;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.List;

public class Pizza {

    private List<Toppings> toppings = new ArrayList<>();
    private Size size;
    private String name;

    public List<Toppings> getToppings() {
        return toppings;
    }

    /**
     * Add a topping to the pizza. The same topping can be added twice to duplicate the amount.
     *
     * @param t
     */
    public void addTopping(Toppings t) {
        if (Collections.frequency(toppings, t) < 2)
            this.toppings.add(t);
    }


    public void setToppings(List<Toppings> toppings) {
        this.toppings = toppings;
    }

    public Size getSize() {
        return size;
    }

    public void setSize(Size size) {
        this.size = size;
    }

    /**
     * Set the pizza Size in cm.
     * A pizza under 15cm is small.
     * Between 15cm and 20cm medium and over 20 cm large.
     *
     * @param dimension
     * @throws IllegalArgumentException if the size is above 25cm
     */
    public void setSize(int dimension) throws IllegalArgumentException {
        if (dimension > 25)
            throw new IllegalArgumentException();
        else if (dimension > 20)
            this.size = Size.LARGE;
        else if (dimension >= 15)
            this.size = Size.MEDIUM;
        else
            this.size = Size.SMALL;
    }

    public String getName() {
        return name;
    }

    /**
     * Set the name of the pizza.  Also special charakters as !=?... are not allowed. If the name is empty a default name is set.
     *
     * @param name
     */
    public void setName(String name) {
        if (name.isEmpty())
            this.name = new Date().toString();
        else
            this.name = name;
    }

    /**
     * Removes the topping t
     *
     * @param t
     */
    public void removeTopping(Toppings t) {
        this.toppings.remove(t);
    }

    public String toString() {
        String toppingString = "";
        for (Toppings t : toppings) {

            toppingString += t + "/";
        }
        return "Name " + getName() + ", Size :" + getSize() + "Toppings:" + toppingString;
    }

    public enum Toppings {Cheese, Tomato, Ham, Chicken, PineApple, Pepperonie}

    ;

    public enum Size {SMALL, MEDIUM, LARGE}

    ;
}
